;; Niche formation parameter sweep (nips) model
;; January 2010

;Copyright 2009, 2010 Antonio Lopolito, Richard Taylor and Piergiuseppe Morone. All rights reserved.
;Please read the full copyright notice in the Information tab.

 


breed [spreaders] 
breed [normals] 

globals [
 ;; NTPw    ;; Network Power - is the sum of the energy of all links
 ;; NTKn    ;; Network Knowledge - is the sum of the knowledge of all links - these are reporters rather than globals
  
  Rsk     ;; Risk - represent the risk in operating in niche option (uncertainty)
  Rskv    ;; Variable component of the risk in operating in niche option (p increases slightly -> Rskv decreases)
  Sbs     ;; Subsidy - Subsidy to the niche option
  Cex     ;; External Cost - external cost of the niche option
  HighEx  ;; level at which an agent becomes active
  IncrEx  ;; amount by which a spreader will increase expectation of a normal
  R       ;; revenues
  R0      ;; revenues at initial time period
  REx     ;; expected revenues
]

normals-own  [ 
  Ex              ;; expectation towards the new tecnology (0 for Opponents, 0,25 for "A little", 0,5 for normals, 0,75 for "A lot", 1 for supporters)
  Kn              ;; Knowledge - endowmwnt of knowledge for the agent in the niche option at time 0
  Pw              ;; Power - endowment of strategic resources for the agent at time 0
  ExPr            ;; Expected profit (eqn. 2)
  U               ;; Utility - outcome gained by choosing the niche option (eqn. 3)
  C               ;; Cost - operation costs of the niche option
  supporter       ;; boolean - supporter true or false
  niche-tech      ;; boolean - uses niche tech true or false
]

links-own    [
  endless?    ;; true if the link has becamed stable
  energy      ;; is the sum of the power of the two ends of the link 
  Knflow      ;; is the sum of the knowledge of the two ends of the link
]

to setup
  clear-all
   
  ;; applied is the user interface switch for theoretical or applied version. set to true for applied version (model will read in data)
  ;; set to false for theoretical simulation (no input data)
    
  if applied [
    ;; calculate N
    set N 0
    file-open "applied-model-firms-data.txt"
    let title file-read-line
    ;;show title
    while [file-at-end? = false] 
    [
       let line file-read-line
       ;;show line
       set N N + 1
    ]
    show N
    file-close
  ]
    
  set Rskv 0.4
  set Rsk  0.1 + Rskv ;; risk has a component which cannot be removed (0.1) and a component (Rskv) that decrease when network knowledge augments  
  set Sbs Subsidy
  set Cex 0.5
  set HighEx 0.75     ;; level at which an agent becomes a supporter
  set IncrEx 0.02     ;; amount by which a spreader will increase expectation of a normal

  set R0 1.5          ;; initial revenues
  set REx 1.5         ;; expected revenues
  set R R0            ;; revenues
  ;; TODO revenues should vary over the time steps?
 
  set-default-shape normals "circle"
  
  if applied [
    file-open  "applied-model-firms-data.txt"
    let title file-read-line
    show (word "reading firms data: " title)
  ]
  create-normals N [;; move each turtle to a random point
    setxy random-xcor random-ycor
    set color green
    set niche-tech false
    set size 0.8
   
    ;; read expectation, knowledge and power from file
    ifelse applied
    [
      set label file-read 
      set Pw file-read
      set Ex file-read
      set Kn file-read
    ]
    [
      set label word "normal" who
      set label ""
      set Kn random-float 0.01 
      set Pw random-float 0.3
      set Ex 0.5 
    ]
    set U 0
    set C 0.5
   ;; show (word label " (who:" who ") Power:" Pw " Expectation:" Ex " Knowledge:" Kn)  
  ]
  
  if applied 
  [
    file-close
    ;; read network file -- set links as endless?
    ;; links can normally only be established between a pair of supporters / niche tech users
    
  ]
  
  create-spreaders NS [;; move each turtle to a random point
  setxy random-xcor random-ycor
  set color white
  set size 1
]
end


to setup-tick
  ;; patch colours indicate risk/uncertainty
  ask patches [
    ifelse random-float 1 < Rsk
      [set pcolor gray - 3 ] ;; randomly distribute Risk  - gray means that half revenues are achieved by niche producers
      [set pcolor black ]     
  ]
  
  ask normals [
  ;; agents with high expectation can form links
    ifelse Ex >= HighEx
      [set supporter true]
      [set supporter false]
  ]
    
end

;; interact with spreaders, and then move both normals and spreaders
to interact-with-spreaders
 
  ;; ask normals [move-to patch-here] ;; this line does not effect anything
  
  ;; each spreader moves once as long as the condition is fulfilled
  foreach sort spreaders [
    if any? normals with [Ex < 1]   ;; condition
    [
      ;; ask spreader to move
      ask ? [  ;; ask spreader
        ;; min-on-of reports the agent in the agentset that has the lowest value for the given reporter 
        ;; [distance myself] reports the distance from this agent to the given turtle or patch - myself is the calling agent i.e. the spreader]. 
        ;; move-to min-one-of other normals with [Ex < 1] [distance myself] ;; 'other' command is not needed
        move-to min-one-of normals with [Ex < 1] [distance myself]
        
        ;; must interact with normal BEFORE doing the getaway procedure
        foreach sort normals-here with [Ex < 1] [
          ask ? [
            set Ex Ex + IncrEx
            if Ex > 1 [set Ex 1]
            ;;getaway 1  ;; normal turns to random direction and moves forward one (if it has interacted)
          ]
        ]
      ]
    ]
    ask ? [getaway 3]  ;; spreader turns to random direction moves forward three
  ] 
  
  ;; now move the normals (whether or not they interacted)
  ask normals [getaway 1]  

end

;; turns to random direction and moves forward specified distance
to getaway [q]
  ;;rt 360 ;; it turns a full circle
  rt random 360
  fd q
end

;; if expected profit > 0 select niche technology 
to select-tech
  ;;compute expected profit (eq. 2)
  ask normals [
    set ExPr (REx * Ex) + Sbs - ((1 / Ex) * (C + Cex)) 
    
    ;; select tech based on the result
    ifelse ExPr > 0
     [
       set niche-tech true
       set color red
     ]
     [
       set color green
       set niche-tech false
     ]
  ]
end

to calculate-utility
;;to shift
 
  ;; for agents producing with niche technology
  ask normals with [niche-tech = true][
    ifelse pcolor = gray - 3
      [set U (R * 0.5) + Sbs - C - Cex]  ;; half revenues are achieved on gray patch (eq. 3 bottom part)
      [set U R + Sbs - C - Cex]          ;; full revenues are achieved on non-gray (eq. 3 top part)
    ;;show (word pcolor ": normal-" who " obtains utility of " U)
    set Pw Pw + U
    if Pw > 100 [set Pw 100]
    set Kn Kn + 0.025
    if Kn > 1 [set Kn 1]
    set C C - Pw * 0.01
    if C < 0.5 [set C 0.5] ;; the operating cost has a component that cannot be eliminated
  ]
end

;; ex will increase any time the actual profit obtained producing with the new technology exceeds the expected profit
;; likewise ex will decrease if it is lower than expected 
to reconsider-expectation
  ask normals with [niche-tech = true]
  [
    set Ex Ex + U
    if Ex > 1 [set Ex 1]
    if Ex < 0 [set Ex 0]
  ]
end
 
to find-partner
  ask normals with [supporter = true] [
    ;; links are made with other supporters of the niche technology in the same location
    create-links-with other normals-here with [supporter = true] 
    [;;tie
      set color green
      set energy ([Pw] of end1 + [Pw] of end2)
      set Knflow (([Kn] of end1) + ([Kn] of end2))
      show (word "created link: " [label] of end1 " with " [label] of end2)
    ]
  ]
end   
 
to update-links
  ask links 
  [
    if not all? both-ends [ex >= HighEx] ;; reports the agentset of the 2 nodes connected by this link. 
    [
       show (word "deleted link: " [label] of end1 " with " [label] of end2)
      die
    ] 
  ] 
end
 
to update-world
  ;; updating of the link variables was done therefore the reporters should be up to date 
  set Rskv Rskv - network-knowledge * 0.01  ;; Rskv decreases (p increases slightly)
   set Cex Cex - network-power * 0.01
   if Cex < 0.5 [set Cex 0.5] ;; the operating cost has a component that cannot be eliminated
   
   
  if Rskv < 0 [set Rskv 0]
  set Rsk  0.1 + Rskv
   
   ;; move to setup tick
   ;; show (word "Rsk: " Rsk)
   ;;ask patches [
   ;;   set pcolor black 
   ;;   if random-float 1 < Rsk [set pcolor gray ]  ;; randomly distribute Risk - gray means that half revenues are achieved
;;] 
end

to go
 ;; plotting goes here so that it gives the same output as the reporters in behaviourspace
 set-current-plot "number of active agents"
 set-current-plot-pen "supporters"
 plot number-supporters
 set-current-plot-pen "niche-producers"
 plot number-niche-producers
 set-current-plot "number of gray patches"
 plot uncertainty
 set-current-plot "Nlinks"
 plot number-links
 set-current-plot "niche-tech average-profit"
 plot average-profit
 set-current-plot "average expectation"
 plot average-expectation
 setup-tick
 
 ;; interact with spreaders, and then move
 interact-with-spreaders
 
 ;; compute expected profit and choose tech based on expectation, 
 select-tech
 
 ;; only red coloured normals will have utility calculated?
 calculate-utility    ;;shift
 
 find-partner
 reconsider-expectation
 
 ;; update links must come before update world in order to use the latest calculations for knowledge and power
 update-links
 update-world
 tick
 
end

to-report number-niche-producers
  report count normals with [niche-tech = true]
end

to-report uncertainty
  report count patches with [pcolor = grey - 3]
end

to-report number-links
  report count links
end

to-report number-supporters
   report count normals with [supporter = true]
end

;; Network Power is the sum of the energy of all links
to-report network-power
  report sum [energy] of links
end

;; Network Knowledge - is the sum of the knowledge of all links
to-report network-knowledge
  report sum [Knflow] of links
end

;; TODO should this be density of links among supporters?
to-report  niche-density
  ifelse number-niche-producers > 1
    [report (count links * 2)/ (number-niche-producers * (number-niche-producers - 1))]
    [report 0]
end

to-report average-profit
  ifelse number-niche-producers > 0
    [
      ;;show mean [U] of normals with [niche-tech = true]
      report mean [U] of normals with [niche-tech = true]
    ]
    [report 0]
end

to-report average-expectation
  report mean [Ex] of normals 
end


@#$#@#$#@
GRAPHICS-WINDOW
205
10
644
470
16
16
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
1
1
1
ticks

SLIDER
9
210
181
243
Subsidy
Subsidy
0
0.35
0
0.01
1
NIL
HORIZONTAL

SLIDER
7
261
179
294
N
N
0
100
100
1
1
NIL
HORIZONTAL

SLIDER
4
303
176
336
NS
NS
0
10
7
1
1
NIL
HORIZONTAL

BUTTON
42
18
129
51
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
53
157
121
190
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
733
38
933
188
number of active agents
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"supporters" 1.0 0 -955883 true
"niche-producers" 1.0 0 -16777216 true

PLOT
732
209
932
359
number of gray patches
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

MONITOR
982
410
1080
455
NIL
Rsk
17
1
11

MONITOR
543
479
640
524
Rsk var%
(0.5 - Rsk) / 0.5
17
1
11

PLOT
983
40
1183
190
Nlinks
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

MONITOR
221
483
319
528
Overall Density
(count links * 2)/ (24 * 23)
17
1
11

MONITOR
375
479
473
524
Niche Density
niche-density
17
1
11

BUTTON
40
115
133
148
go 1-tick
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
734
390
934
540
niche-tech average-profit
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

SWITCH
32
73
140
106
applied
applied
1
1
-1000

PLOT
986
209
1186
359
average expectation
NIL
NIL
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

@#$#@#$#@
HOW TO CITE
-----------
If you mention this model in an academic publication, we ask that you include these citations for the model itself and for the NetLogo software:

Lopolito, A., R. Taylor and P. Morone (2010). NetLogo "Emerging innovation niches model". CoMSES Computational Model Library. 
 

COPYRIGHT NOTICE
----------------
Copyright 2009, 2010 Antonio Lopolito, Richard Taylor and Piergiuseppe Morone. All rights reserved.
This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. 

This model has been used for the analysis published in 
"Lopolito, A., Morone, P., Taylor, R. 2013. Emerging innovation niches: An agent based model. Research Policy, 42 (6-7), pp. 1225-1238, ISSN: 00487333, DOI: 10.1016/j.respol.2013.03.002"
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="specific-policy-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <steppedValueSet variable="Subsidy" first="0" step="0.05" last="0.25"/>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="24"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-is-0.2-NS-is-5-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.2"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-is-0.25-NS-is-5-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.25"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-is-0-NS-is-5-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-is-0-05-NS-is-zero-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-is-0-05-NS-is-5-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-is-003-NS-is-3-batch-100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS3_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS3_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS3_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS5_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS5_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS5_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS7_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS7_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS7_batch100" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS3_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS3_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS3_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS5_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS5_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS5_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS7_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS7_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS7_batch100_5000" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="4999"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS3_batch100_prova" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS5_batch100_prova" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="499"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-0-NS-6-N-50-batch-10" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="10"/>
    <enumeratedValueSet variable="NS">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs-0-NS-7-N-70-batch-10" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="10"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="70"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS5_N100_S2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.09"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS7_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS7_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS7_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS7_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.09"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS9_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.09"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS1_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.09"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS2_N100_ST2700" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.09"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS1_N100_ST2700_EXincr002" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.09"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs007_NS1_N100_ST2700_EXincr002" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs005_NS1_N100_ST2700_EXincr002" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.05"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs003_NS1_N100_ST2700_EXincr002" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0.03"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs0_NS7_N100_ST2700_EXincr002" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Sbs009_NS1_N100_ST2700_EXincr002_baseline_mod" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2699"/>
    <metric>number-niche-producers</metric>
    <metric>number-supporters</metric>
    <metric>average-profit</metric>
    <metric>uncertainty</metric>
    <metric>number-links</metric>
    <metric>network-power</metric>
    <metric>network-knowledge</metric>
    <metric>niche-density</metric>
    <enumeratedValueSet variable="Subsidy">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="random-seed" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="NS">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
